pub struct SourceMapCacheWriter { /* private fields */ }Expand description
A structure that allows quick resolution of minified source position to the original source position it maps to.
Implementations
sourceimpl SourceMapCacheWriter
impl SourceMapCacheWriter