pub struct SourceMapCacheWriter { /* private fields */ }
A structure that allows quick resolution of minified source position to the original source position it maps to.

Implementations

Constructs a new Cache from a minified source file and its corresponding SourceMap.

Serialize the converted data.

This writes the SourceMapCache binary format into the given Write.